import Foundation

final class FeedPageGenerator {

    let content: Content

    init(content: Content) {
        self.content = content
    }

    private func includeSwiper(in headers: inout Set<HeaderElement>) {
        if let swiperCss = content.settings.posts.swiperCssFile {
            headers.insert(.css(file: swiperCss, order: HeaderElement.swiperCssFileOrder))
        }
        if let swiperJs = content.settings.posts.swiperJsFile {
            headers.insert(.js(file: swiperJs, defer: true))
        }
    }

    func generatePage(language: ContentLanguage,
                      posts: [FeedEntryData],
                      title: String,
                      description: String,
                      showTitle: Bool,
                      pageNumber: Int,
                      totalPages: Int) -> String {
        var headers = content.defaultPageHeaders
        var footer = ""
        if posts.contains(where: { $0.images.count > 1 }) {
            // Sort swiper style sheet before default style sheet
            includeSwiper(in: &headers)
            footer = swiperInitScript(posts: posts)
        }

        let page = GenericPage(
            language: language,
            title: title,
            description: description,
            links: content.navigationBar(in: language),
            headers: headers,
            additionalFooter: footer) { content in
                if showTitle {
                    content += "<h1>\(title)</h1>"
                }
                for post in posts {
                    content += FeedEntry(data: post).content
                }
                if totalPages > 1 {
                    content += PostFeedPageNavigation(currentPage: pageNumber, numberOfPages: totalPages, language: language).content
                }

            }
        return page.content
    }

    func swiperInitScript(posts: [FeedEntryData]) -> String {
        var result = "<script> window.onload = () => { "
        for post in posts {
            guard post.images.count > 1 else {
                continue
            }
            result += ImageGallery.swiperInit(id: post.entryId)
        }
        result += "}; </script>"
        return result
    }
}
