import Foundation

/**
 A string key used in markdown to indicate special elements
 */
enum ShorthandMarkdownKey: String {

    /// An image
    /// Format:  `![image](<imageId>;<caption?>]`
    case image

    /// Labels with an icon and a value
    /// Format: `![labels](<icon=value>...)`
    case labels

    /// A video
    /// Format: `![video](<fileId>;<option1...>]`
    case video

    /// A variable number of download buttons for file downloads
    /// Format: `[buttons](type=<<fileId>,<text>,<download-filename?>;...)`
    case buttons

    /// A box with a title and content
    /// Format: `![box](<title>;<body>)`
    case box

    /// A 3D model to display
    /// Format: `![model](<file>;<description>)`
    case model

    /// A pretty link to another page on the site.
    /// Format: `![page](<pageId>)`
    case pageLink = "page"

    /// A pretty link to a tag list on the site.
    /// Format: `![tag](<tagId>)`
    case tagLink = "tag"

    /// Additional HTML code include verbatim into the page.
    /// Format: `![html](<fileId>)`
    case includedHtml = "html"

    /// SVG Image showing only a part of the image
    /// Format `![svg](<fileId>;<<x>;<y>;<width>;<height>>?)`
    case svg

    /// A player to play audio files
    /// Format: `![audio-player](<fileId>;<text>)`
    case audioPlayer = "audio-player"

}
