import Foundation
import SwiftUI
import Combine

final class Content: ObservableObject {

    @ObservedObject
    var storage = Storage()

    @Published
    var settings: Settings

    @Published
    var posts: [Post]

    @Published
    var pages: [Page]

    @Published
    var tags: [Tag]

    @Published
    var files: [FileResource]

    @Published
    var tagOverview: TagOverviewPage?

    @Published
    private(set) var results: [ItemId : PageGenerationResults] = [:]

    @Published
    private(set) var isGeneratingWebsite = false

    init(settings: Settings,
         posts: [Post],
         pages: [Page],
         tags: [Tag],
         files: [FileResource],
         tagOverview: TagOverviewPage?) {
        self.settings = settings
        self.posts = posts
        self.pages = pages
        self.tags = tags
        self.files = files
        self.tagOverview = tagOverview
    }

    init() {
        self.settings = .mock
        self.posts = []
        self.pages = []
        self.tags = []
        self.files = []
        self.tagOverview = nil
    }

    var images: [FileResource] {
        files.filter { $0.type.isImage }
    }

    func set(isGenerating: Bool) {
        DispatchQueue.main.async {
            self.isGeneratingWebsite = isGenerating
        }
    }

    func add(_ file: FileResource) {
        // TODO: Insert at correct index?
        files.insert(file, at: 0)
    }

    func add(_ page: Page) {
        // TODO: Insert at correct index?
        pages.insert(page, at: 0)
    }
}
