import Foundation

struct GenericPage {

    let language: ContentLanguage

    let title: String

    let description: String

    let links: [NavigationBar.Link]

    let headers: [HeaderElement]

    let additionalFooter: String

    let insertedContent: (inout String) -> Void

    init(language: ContentLanguage, title: String, description: String, links: [NavigationBar.Link], headers: Set<HeaderElement>, additionalFooter: String, insertedContent: @escaping (inout String) -> Void) {
        self.language = language
        self.title = title
        self.description = description
        self.links = links
        self.headers = headers.union([.title(title), .description(description)]).sorted()
        self.additionalFooter = additionalFooter
        self.insertedContent = insertedContent
    }
    
    var content: String {
#warning("Consolidate this code with ContentPage")
        var result = ""
        result += "<!DOCTYPE html><html lang=\"\(language.rawValue)\">"
        result += PageHead(items: headers).content
        result += "<body>"
        result += NavigationBar(links: links).content
        result += "<div class=\"content\"><div style=\"height: 70px;\"></div>"
        insertedContent(&result)
        result += "</div>"
        result += additionalFooter
        result += "</body></html>" // Close content
        return result
    }
}
