import SwiftUI

struct LocalizedTagDetailView: View {
    
    @ObservedObject
    var tag: LocalizedTag
    
    @EnvironmentObject
    private var content: Content
    
    @State
    private var showImagePicker = false
    
    var body: some View {
        VStack(alignment: .leading) {
            StringPropertyView(
                title: "Name",
                text: $tag.name,
                footer: "The displayed name of the tag")
            
            IdPropertyView(
                id: $tag.urlComponent,
                title: "Page URL String",
                footer: "The url component to use in the url for this tag",
                validation: tag.isValid,
                update: { tag.urlComponent = $0 })
            
            Text("Original url")
                .font(.headline)
            Text(tag.originalUrl ?? "-")
                .foregroundStyle(.secondary)
                .padding(.top, 1)
                .padding(.bottom)
            
            OptionalStringPropertyView(
                title: "Subtitle",
                text: $tag.subtitle,
                footer: "The subtitle/tagline to use")
            
            OptionalImagePropertyView(
                title: "Preview Image",
                selectedImage: $tag.linkPreviewImage,
                footer: "The image to show for previews of this page")
            
            OptionalTextFieldPropertyView(
                title: "Preview Description",
                text: $tag.description,
                footer: "The description to show in previews of the page")
        }
    }
}

#Preview {
    LocalizedTagDetailView(tag: Tag.mock.english)
}
